<?php

class FocusSitecallLite_Add_Widget {
	const SITECALL_WIDGET = 'sitecalllite_widget';
	const SITECALL_GLOBAL_WIDGET = 'sitecalllite_global_widget';
	const SITECALL_TEMPLATE_WIDGET = 'sitecalllite_template_widget';

	public function register_actions() {
		add_action( 'add_meta_boxes', array( $this, 'page_widget_dropdown' ) );
		add_action( 'save_post', array( $this, 'save_post' ) );
	}

	public static function add_to_footer() {
		global $post;

        if( isset($post->ID) && isset(get_post_meta($post->ID)[self::SITECALL_WIDGET]) ) {
            $postMeta = get_post_meta($post->ID);
            $widgetId = is_array($postMeta[self::SITECALL_WIDGET]) ? $postMeta[self::SITECALL_WIDGET] : [];

            switch (current($widgetId)) {
                default:
                    $widget = FocusSitecallLite_Sitecalls_Model::getWidgetById(current($widgetId));
                    if (!empty($widget) || current($widgetId) == 0) {
                        break;
                    }
                case self::SITECALL_TEMPLATE_WIDGET:
                    $templateWidget = FocusSitecallLite_Templates_Sitecalls_Model::getDefaultTemplateWidget($postMeta, $post->ID);
                    $widget = FocusSitecallLite_Templates_Sitecalls_Model::assignActiveGlobalWidget($templateWidget);
                    if (!empty($widget)) {
                        break;
                    }
                case self::SITECALL_GLOBAL_WIDGET:
                    $widgetUuid = get_option(FocusSitecallLite_Model::SITECALL_DEFAULT_GLOBAL_OPTION_KEY);
                    $globalWidget = FocusSitecallLite_Sitecalls_Model::getWidgetById($widgetUuid);
                    $widget = FocusSitecallLite_Templates_Sitecalls_Model::assignActiveTemplateWidget($globalWidget, $postMeta, $post->ID);
                    break;
            }

        } else {
            $widgetUuid = get_option(FocusSitecallLite_Model::SITECALL_DEFAULT_GLOBAL_OPTION_KEY);
            $globalWidget = FocusSitecallLite_Sitecalls_Model::getWidgetById($widgetUuid);

            if (!empty($globalWidget)) {
                $widget = $globalWidget;
            }
        }


		if ( ! empty( $widget ) ) {
	        $pasteCode = '<script>';

            $pasteCode .= 'var FocusSitecallLite = ' . json_encode(FocusSitecallLite_Sitecalls_Model::getConfiguration($widget['id'])) . ';';

            $pasteCode .= '</script>';

            $pasteCode .= '<script src="' . plugins_url( '/public/widget.js', __FILE__ ) . '"></script>';

            echo $pasteCode;
        }

	}

	public function save_post( $post_id ) {

        if ( 'trash' != get_post_status( $post_id ) ) {
            $post_meta = get_post_meta($post_id);
            $defaultTemplateWidget = FocusSitecallLite_Templates_Sitecalls_Model::getDefaultTemplateWidget($post_meta, $post_id);
            $defaultGlobalWidget = get_option(FocusSitecallLite_Model::SITECALL_DEFAULT_GLOBAL_OPTION_KEY);

            if (!isset($post_meta[self::SITECALL_WIDGET])) {
                $this->assignWidgetToNewPage($defaultGlobalWidget, $defaultTemplateWidget, $post_id);
            } else {
                update_post_meta($post_id, self::SITECALL_WIDGET, sanitize_text_field( $_POST[self::SITECALL_WIDGET] ));
            }
        }
	}

	public function page_widget_dropdown() {
		add_meta_box(
			'FocusSiteCallLite_widget_dropdown',
			'Focus SiteCall Lite',
			array( $this, 'process_dropdown' ),
			'page',
			'side',
			'low',
			FocusSitecallLite_Sitecalls_Model::getAll()
		);
	}

	public function process_dropdown( $post, $metaData ) {
		$postMeta = get_post_meta( $post->ID );
		$widgetId = isset( $postMeta[ self::SITECALL_WIDGET ] ) && is_array( $postMeta[ self::SITECALL_WIDGET ] ) ? current( $postMeta[ self::SITECALL_WIDGET ] ) : [];
		$output   = sprintf( '<select name="%s">', self::SITECALL_WIDGET );

		if ( ! empty( $metaData['args'] ) ) {
			$defaultOption = $this->getDefaultOption( $metaData['args'], $widgetId );

			if ( ! $defaultOption ) {
				$output .= '<option value="0" selected="selected">' . __('(none)', 'focus-sitecall-lite') . '</option>';
			} else {
				$output .= '<option value="0">' . __('(none)', 'focus-sitecall-lite') . '</option>';
			}

			$defaultTemplateWidget = FocusSitecallLite_Templates_Sitecalls_Model::getDefaultTemplateWidget( $postMeta, $post->ID );
			if ( ! empty( $defaultTemplateWidget ) ) {
				if ( $defaultOption === self::SITECALL_TEMPLATE_WIDGET ) {
					$output .= sprintf( '<option value="%s" selected="selected">' . __('Default for template(%s)', 'focus-sitecall-lite') . '</option>', self::SITECALL_TEMPLATE_WIDGET, $defaultTemplateWidget['name'] );
				} else {
					$output .= sprintf( '<option value="%s">' . __('Default for template(%s)', 'focus-sitecall-lite') . '</option>', self::SITECALL_TEMPLATE_WIDGET, $defaultTemplateWidget['name'] );
				}
			}

			$defaultGlobalWidgetId = get_option( FocusSitecallLite_Model::SITECALL_DEFAULT_GLOBAL_OPTION_KEY );
			if ( isset( $defaultGlobalWidgetId ) && $defaultGlobalWidgetId !== FocusSitecallLite_Sitecalls_Model::NO_WIDGETS_DEFINED ) {
				$globalWidget = FocusSitecallLite_Templates_Sitecalls_Model::getWidgetIfExists( $defaultGlobalWidgetId );
				if ( $defaultOption === self::SITECALL_GLOBAL_WIDGET ) {
					$output .= sprintf( '<option value="%s" selected="selected">' . __('Default for theme(%s)', 'focus-sitecall-lite') . '</option>', self::SITECALL_GLOBAL_WIDGET, $globalWidget['name'] );
				} elseif (!empty($globalWidget)) {
					$output .= sprintf( '<option value="%s">' . __('Default for theme(%s)', 'focus-sitecall-lite') . '</option>', self::SITECALL_GLOBAL_WIDGET, $globalWidget['name'] );
				}
			}

			foreach ( $metaData['args'] as $widget ) {
				if ( $widget['id'] === $defaultOption ) {
					$output .= sprintf( '<option value="%s" selected="selected">%s</option>', $widget['id'], $widget['name'] );
				} else {
					$output .= sprintf( '<option value="%s">%s</option>', $widget['id'], $widget['name'] );
				}
			}
		} else {
			$output .= '<option selected="selected">' . __('No defined widgets', 'focus-sitecall-lite') . '</option>';
		}
		$output .= '</select>';

		echo $output;
	}

	private function getDefaultOption( $widgets, $widgetId ) {
		switch ( $widgetId ) {
			case self::SITECALL_GLOBAL_WIDGET:
				$defaultOption = self::SITECALL_GLOBAL_WIDGET;
				break;
			case self::SITECALL_TEMPLATE_WIDGET:
				$defaultOption = self::SITECALL_TEMPLATE_WIDGET;
				break;
			default:
				foreach ( $widgets as $widget ) {
					if ( $widget['id'] === $widgetId ) {
						$defaultOption = $widgetId;
					}
				}
		}

		return isset( $defaultOption ) ? $defaultOption : false;
	}

	private function assignWidgetToNewPage( $defaultGlobalWidget, $defaultTemplateWidget, $post_id ) {
		if ( isset( $post_meta['_wp_page_template'] ) || isset( $defaultTemplateWidget['id'] ) ) {
			add_post_meta( $post_id, self::SITECALL_WIDGET, self::SITECALL_TEMPLATE_WIDGET );
		} elseif ( $defaultGlobalWidget && $defaultGlobalWidget !== "0" ) {
			add_post_meta( $post_id, self::SITECALL_WIDGET, self::SITECALL_GLOBAL_WIDGET );
		} else {
			add_post_meta( $post_id, self::SITECALL_WIDGET, self::SITECALL_TEMPLATE_WIDGET );
		}
	}
}

add_action( 'wp_footer', array( 'FocusSitecallLite_Add_Widget', 'add_to_footer' ) );
