<?php

require_once( 'class.focussitecalllite-model.php' );
require_once( 'class.focussitecalllite-sitecalls-model.php' );
require_once( 'class.focussitecalllite-notices.php' );

require_once( 'class.focussitecalllite-sitecall-agreements-model.php' );

class FocusSitecallLite_Admin_Post_Controller {
	public function register_actions() {
		add_action( 'admin_post_focussitecalllite_assign_sitecalls', array( $this, 'assign_sitecalls' ) );
		add_action( 'admin_post_focussitecalllite_update_credentials', array( $this, 'update_credentials' ) );
		add_action( 'admin_post_focussitecalllite_save_sitecall', array( $this, 'save_sitecall' ) );
		add_action( 'admin_post_focussitecalllite_actions_on_sitecalls', array( $this, 'actions_on_sitecalls' ) );
	}

	public function assign_sitecalls() {
		if ( isset( $_POST['default_global_sitecall_button'] ) ) {
			update_option( FocusSitecallLite_Model::SITECALL_DEFAULT_GLOBAL_OPTION_KEY, sanitize_text_field( $_POST['default_global_sitecall'] ) );
			$success = true;
			$message = __('SiteCall`s assigment to themes was updated.', 'focus-sitecall-lite');
		} elseif ( isset( $_POST['assignTo'] ) && current( $_POST['assignTo'] ) !== "-1" ) {
			$assignTo =  sanitize_text_field( current( $_POST['assignTo'] ) );
			if ( ! empty( $_POST['bulk-assign'] ) && is_array( $_POST['bulk-assign'] ) && isset( $assignTo ) ) {
                $_POST['bulk-assign'] = array_map( 'sanitize_text_field', $_POST['bulk-assign'] );
			    $templates_sitecall_list = FocusSitecallLite_Templates_Sitecalls_Model::getAll();

				foreach ( $_POST['bulk-assign'] as $template ) {
					if ( $assignTo === '0' ) {
						unset( $templates_sitecall_list[ $template ] );
					} else {
						$templates_sitecall_list[ $template ] = $assignTo;
					}
				}
				FocusSitecallLite_Templates_Sitecalls_Model::setAll( $templates_sitecall_list );

				$success = true;
				$message = __('Assigned to templates.', 'focus-sitecall-lite');
			} else {
				$success = false;
				$message = __('Not assigned to templates.', 'focus-sitecall-lite');
			}
		}

		$this->redirect( $_POST['_wp_http_referer'], $success, $message );
	}

    public function actions_on_sitecalls()
    {
        if ( isset( $_POST['delete_sitecalls_button']) && isset($_POST['bulk-delete']) ) {

            $_POST['bulk-delete'] = array_map('sanitize_text_field', $_POST['bulk-delete']);

            $allSitecalls = FocusSitecallLite_Sitecalls_Model::getAll();

            $deleted = 0;

            foreach ($_POST['bulk-delete'] as $siteCallToDelete) {
                $sitecallKey = array_search($siteCallToDelete, array_column($allSitecalls, 'id'));

                unset($allSitecalls[$sitecallKey]);

                $allSitecalls = array_values($allSitecalls);

                $deleted++;
            }

            FocusSitecallLite_Sitecalls_Model::setAll($allSitecalls);

            if ($deleted) {
                $success = true;
                $message = __('Selected SiteCall widgets were deleted', 'focus-sitecall-lite');
            } else {
                $success = false;
                $message = __('Selected SiteCall widgets were not deleted', 'focus-sitecall-lite');
            }
        } else {
            $success = false;
            $message = __('Not deleted selected SiteCall widgets', 'focus-sitecall-lite');
        }
        $this->redirect( $_POST['_wp_http_referer'], $success, $message );
    }


	public function save_sitecall()
    {
        $allSitecalls = FocusSitecallLite_Sitecalls_Model::getAll();

            $sitecallKey = array_search($_POST['id'], array_column($allSitecalls, 'id'));

            $agreements = [];

            $tabEdit = false;

            if (isset($_POST['FocusSitecallLite_sitecallSettings_optionAgreements'])) {

                $agreementsR = isset($_POST['agreement-requirement']) ? $_POST['agreement-requirement'] : [];

                $agreements = $_POST['FocusSitecallLite_sitecallSettings_optionAgreements'];

                array_walk($agreements, function(&$item, $key) use ($agreementsR)  {
                    $item = [
                        'id' => sanitize_text_field( $key ),
                        'description' => sanitize_textarea_field( $item ),
                        'required' => in_array($key, $agreementsR)
                    ];
                });

                $agreements = array_values($agreements);
            }

            $dataToSave = [
                'id' => sanitize_text_field( $_POST['id'] ),
                'name' => sanitize_text_field( $_POST['FocusSitecallLite_sitecallSettings_optionGeneral']['sitecallName'] ),
                'data' => [
                    'general' => [
                        'windowBackgroundColor' => sanitize_text_field( $_POST['FocusSitecallLite_sitecallSettings_optionGeneral']['sitecallWindowBackgroundColor'] ),
                        'launcherBackgroundColor' => sanitize_text_field( $_POST['FocusSitecallLite_sitecallSettings_optionGeneral']['sitecallLauncherBackgroundColor'] ),
                        'buttonColor' => sanitize_text_field( $_POST['FocusSitecallLite_sitecallSettings_optionGeneral']['sitecallButtonColor'] ),
                        'css' => sanitize_textarea_field( $_POST['FocusSitecallLite_sitecallSettings_optionGeneral']['sitecallCss'] ),
                        'counter' => $sitecallKey !== false && isset($allSitecalls[$sitecallKey]['data']['general']['counter']) ? $allSitecalls[$sitecallKey]['data']['general']['counter'] : 0,
                        'counterLastUpdated' => $sitecallKey !== false && isset($allSitecalls[$sitecallKey]['data']['general']['counterLastUpdated']) ? $allSitecalls[$sitecallKey]['data']['general']['counterLastUpdated'] : current_time('Y-m-d'),
                        'launcherPosition' => sanitize_text_field( $_POST['FocusSitecallLite_sitecallSettings_optionGeneral']['sitecallPosition'] ),
                        'connections' => $sitecallKey !== false && isset($allSitecalls[$sitecallKey]['data']['general']['connections']) ? $allSitecalls[$sitecallKey]['data']['general']['connections'] : 0
                    ],
                    'call' => [
                        'headerText' => sanitize_textarea_field( $_POST['FocusSitecallLite_sitecallSettings_optionCall']['sitecallCallText1'] ),
                        'footerText' => sanitize_textarea_field( $_POST['FocusSitecallLite_sitecallSettings_optionCall']['sitecallCallText2'] ),
                        'goNextButton' => sanitize_textarea_field( $_POST['FocusSitecallLite_sitecallSettings_optionCall']['sitecallCallGoNextButton'] )
                    ],
                    'recall' => [
                        'headerText' => sanitize_textarea_field( $_POST['FocusSitecallLite_sitecallSettings_optionRecall']['sitecallRecallText1'] ),
                        'goNextButton' => sanitize_textarea_field( $_POST['FocusSitecallLite_sitecallSettings_optionRecall']['sitecallRecallGoNextButton'] )
                    ],
                    'afterCall' => [
                        'headerText' => sanitize_textarea_field( $_POST['FocusSitecallLite_sitecallSettings_optionAfterCall']['sitecallAfterCallText1'] ),
                        'goNextButton' => sanitize_textarea_field( $_POST['FocusSitecallLite_sitecallSettings_optionAfterCall']['sitecallAfterCallGoNextButton'] )
                    ],
                    'agreementsStep' => [
                        'headerText' => sanitize_textarea_field( $_POST['FocusSitecallLite_sitecallSettings_section_agreements']['sitecallAgreementsHeaderText'] ),
                        'requiredFieldLabel' => sanitize_textarea_field( $_POST['FocusSitecallLite_sitecallSettings_section_agreements']['sitecallAgreementsRequirmentFieldLabel'] ),
                        'goNextButton' => sanitize_textarea_field( $_POST['FocusSitecallLite_sitecallSettings_section_agreements']['sitecallAgreementsButtonText'] )
                    ],
                    'agreements' => $agreements
                ]
            ];


            if ($sitecallKey !== false) {
                $allSitecalls[$sitecallKey] = $dataToSave;
            } else {
                $allSitecalls[] = $dataToSave;
            }

            FocusSitecallLite_Sitecalls_Model::setAll($allSitecalls);


        if (isset($_POST['add_agreement_button'])) {

            $success = FocusSiteCallLite_Sitecall_Agreements_Model::addNewAgreement(sanitize_text_field( $_POST['id'] ));

            if ($success) {
                $message = __('New agreement was added', 'focus-sitecall-lite');
            } else {
                $message = __('New agreement was not added', 'focus-sitecall-lite');
            }

            $tabEdit = true;

        }

        if (isset($_POST['delete_agreements_button']) && isset($_POST['bulk-delete'])) {
            $_POST['bulk-delete'] = array_map('sanitize_text_field', $_POST['bulk-delete']);
            $success = FocusSiteCallLite_Sitecall_Agreements_Model::deleteAgreements(sanitize_text_field( $_POST['id'] ), $_POST['bulk-delete']);

            if ($success) {
                $message = __('Selected agreements were deleted', 'focus-sitecall-lite');
            } else {
                $message = __('Selected agreements were deleted', 'focus-sitecall-lite');
            }

            $tabEdit = true;
        } elseif(isset($_POST['delete_agreements_button'])) {
            $tabEdit = true;
            $success = false;
            $message = __('Selected agreements were deleted', 'focus-sitecall-lite');
        }

            $success = isset($success) ? $success : true;
            $message = isset($message) ? $message : __('SiteCall was created/updated', 'focus-sitecall-lite');


            $redirectUrl = str_replace('&tab=agreements', '', $_POST['_wp_http_referer'] );
            $redirectUrl = $tabEdit ? $redirectUrl . '&tab=agreements' : $redirectUrl ;

            $this->redirect( $redirectUrl, $success, $message );
    }

	    public function update_credentials()
        {
            if ( isset( $_POST['FocusSitecallLite_credentials_option'] ) ) {

                $_POST['FocusSitecallLite_credentials_option'] = array_map('sanitize_text_field', $_POST['FocusSitecallLite_credentials_option']);

            /*mail validation*/
		    $explodedEmailAdresses = explode(',', sanitize_text_field( $_POST['FocusSitecallLite_credentials_option']['emailAddressNotification']) );

            $isValid = true;

            foreach($explodedEmailAdresses as $explodedEmailAdress) {
                if (!is_email(trim($explodedEmailAdress))) {
                    $isValid = false;
                    break;
                }
            }
            /*mail validation*/


            if ($isValid) {
                update_option( 'FocusSitecallLite_credentials_option', $_POST['FocusSitecallLite_credentials_option'] );
                $success = true;
                $message = __('Email address notification was changed', 'focus-sitecall-lite');
            } else {
                $success = false;
                $message = __('Invalid email/emails adresses', 'focus-sitecall-lite');
            }

		} else {
            $success = false;
            $message = __('Email address notification was not changed', 'focus-sitecall-lite');
		}

        $this->redirect( $_POST['_wp_http_referer'], $success, $message );
	}

	private function redirect( $url, $success, $message ) {
		if ( $success ) {
			$type = FocusSitecallLite_Notices::NOTICE_SUCCESS;
		} else {
			$type = FocusSitecallLite_Notices::NOTICE_ERROR;
		}
		FocusSitecallLite_Notices::setNotice( $type, $message );

		wp_redirect( $url );
	}

}
