<?php

class FocusSiteCallLite_Sitecall_Agreements_List_Table extends WP_List_Table
{
    private $widgetId;

    public function __construct( $widgetId, $args = array() ) {
        $this->widgetId = $widgetId;
        parent::__construct( $args );
    }

    public function prepare_items() {
        $columns  = $this->get_columns();
        $hidden   = $this->get_hidden_columns();
        $sortable = $this->get_sortable_columns();
        $data     = $this->table_data();

        usort( $data, array( &$this, 'sort_data' ) );

        $perPage = 10;

        $currentPage = $this->get_pagenum();
        $totalItems  = count( $data );
        $this->set_pagination_args( array(
            'total_items' => $totalItems,
            'per_page'    => $perPage
        ) );
        $data                  = array_slice( $data, ( ( $currentPage - 1 ) * $perPage ), $perPage );
        $this->_column_headers = array( $columns, $hidden, $sortable );
        $this->items           = $data;
    }

    public function get_columns() {
        $columns = array(
            'cb'     => '<input type="checkbox" />',
            'agreementTextarea'     => __('Agreement', 'focus-sitecall-lite'),
            'agreementRequire'     => __('Agreement requirement', 'focus-sitecall-lite'),
        );

        return $columns;
    }

    public function get_hidden_columns() {
        return array();
    }

    public function get_sortable_columns() {
        return array();
    }

    private function table_data() {
        $allAgreements = FocusSiteCallLite_Sitecall_Agreements_Model::getAgreementsByWidgetId($this->widgetId);

        $allAgreements = array_map(function ($item) {
            $item['agreementTextarea'] = FocusSiteCallLite_Tools::createField([
                    'type' => 'textarea',
                    'id' => $item['id'],
                    'value' => $item['description'],
                    'optionGroupName' => 'FocusSitecallLite_sitecallSettings_optionAgreements',
                    'style' => 'height:10em; width:40em;',
                    'echo' => false
            ]);

            $item['agreementRequire'] = sprintf('<input type="checkbox" name="agreement-requirement[]" %s value="%s">',
                $item['required'] ? 'checked' : '',
                $item['id']);

            return $item;
        }, $allAgreements);

       return $allAgreements;
    }

    public function column_default( $item, $column_name ) {
        switch ( $column_name ) {
            case 'id':
            case 'agreementTextarea':
            case 'agreementRequire':
                return $item[ $column_name ];
            default:
                return '';
        }
    }

    public function column_cb( $item ) {
        return sprintf(
            '<input type="checkbox" name="bulk-delete[]" value="%s" />', $item['id']
        );
    }

    public function get_bulk_actions() {
        return [];
    }

    public function extra_tablenav( $which ) {
        if ($which == 'top') {

            echo '<input type="submit" name="add_agreement_button" value="' . __('Add', 'focus-sitecall-lite') . '" class="button" />';
            echo '<input type="submit" name="delete_agreements_button" value="' . __('Delete', 'focus-sitecall-lite') . '" class="button" />';

        }
    }


}
