<?php

require_once( 'class.focussitecalllite-model.php' );

class FocusSitecallLite_Sitecalls_Model extends FocusSitecallLite_Model {
	const SITECALL_SITECALLS_OPTION_KEY = 'FocusSitecallLite_sitecalls';
	const NO_WIDGETS_DEFINED = "-1";
	const NAME = 'name';

	const COUNTER_MIN_HOUR = 8;
	const COUNTER_MAX_HOUR = 16;
	const COUNTER_INCREASE = 'increaseCounter';

    const CONNECTIONS_INCREASE = 'increaseConnections';

	public static function getAll() {
		return self::getAllByKey( self::SITECALL_SITECALLS_OPTION_KEY );
	}

	public static function setAll( $data ) {
		self::setAllByKey( $data, self::SITECALL_SITECALLS_OPTION_KEY );
	}

	public static function getWidgetById( $widgetId ) {
		return self::processGetValue( $widgetId );
	}

	public static function getDropdown( $selectId, array $firstOptionData = [], $defaultSelected = null ) {
		$sitecalls = self::getAll();

		$output = '';
		$output .= sprintf( '<select name="%s">', $selectId );
		if ( $sitecalls ) {
			if ( ! empty( $firstOptionData ) ) {
				$output .= sprintf( '<option value="%s">%s</option>', $firstOptionData['value'], $firstOptionData['name'] );
			}

			foreach ( $sitecalls as $sitecall ) {
				$output .= sprintf( '<option %s value="%s">%s</option>',
					$defaultSelected == $sitecall['id'] ? 'selected="selected"' : '',
					$sitecall['id'],
					$sitecall['name'] );
			}
			$output .= '</select>';
		} else {
			$output .= sprintf( '<option value="%s" selected="selected">%s</option>', self::NO_WIDGETS_DEFINED, __('No defined widgets', 'focus-sitecall-lite') );
		}

		return $output;
	}

	private static function processGetValue( $widgetId, $key = null ) {
		$widgets = self::getAll();

		$result = [];
		foreach ( $widgets as $widget ) {
			if ( isset($widget['id']) && $widget['id'] === $widgetId ) {
				if ( is_null( $key ) ) {
					$result = $widget;
				} else {
					$result = $widget[ $key ];
				}
				break;
			}
		}

		return $result;
	}

	public static function setCounter( $widgetId, $counter = self::COUNTER_INCREASE)
    {
        $allSitecalls = self::getAll();
        $sitecallKey = array_search($widgetId, array_column($allSitecalls, 'id'));

        if ($sitecallKey === false) {
            return false;
        }

        if (!isset($allSitecalls[$sitecallKey]['data']['general']['counter'])) {
            $allSitecalls[$sitecallKey]['data']['general']['counter'] = 0;
        }

        if ($counter === self::COUNTER_INCREASE) {
            $allSitecalls[$sitecallKey]['data']['general']['counter']++;
        } else {
            $allSitecalls[$sitecallKey]['data']['general']['counter'] = $counter;
        }
        $allSitecalls[$sitecallKey]['data']['general']['counterLastUpdated'] = current_time('Y-m-d');

        self::setAll($allSitecalls);

        return true;
    }

    public static function getConfiguration( $widgetId )
    {
        $data = self::getWidgetById($widgetId);
        $data['data']['general']['counter'] = self::prepareCounter($widgetId);

        return array(
            'configuration' => $data,
            'baseUrl' => plugins_url( '', __FILE__ ),
            'callbacks' => [
                'sendMessage' => [
                    'url' => admin_url( 'admin-ajax.php' ) . '?action=focussitecalllite-callback',
                    'method' => 'POST',
                    'data' => [
                        'action' => 'focussitecalllite-callback'
                    ]
                ]
            ]
        );
    }

    private static function prepareCounter($widgetId)
    {
        $widgetData = self::getWidgetById($widgetId);

        if ($widgetData['data']['general']['counterLastUpdated'] < current_time('Y-m-d')) {
            $widgetData['data']['general']['counter'] = 0;
            self::setCounter($widgetId, 0);
        }

        $currentHour = current_time('H');

        if ($currentHour < self::COUNTER_MIN_HOUR) {
            $counter = $widgetData['data']['general']['counter'];
        } elseif ($currentHour >= self::COUNTER_MIN_HOUR && $currentHour <= self::COUNTER_MAX_HOUR) {
            $counter = ($currentHour - self::COUNTER_MIN_HOUR + 1) + $widgetData['data']['general']['counter'];
        } else {
            $counter = (self::COUNTER_MIN_HOUR + 1) + $widgetData['data']['general']['counter'];
        }

        return $counter;
    }

    public static function setConnections( $widgetId, $connections = self::CONNECTIONS_INCREASE)
    {
        $allSitecalls = self::getAll();
        $sitecallKey = array_search($widgetId, array_column($allSitecalls, 'id'));

        if ($sitecallKey === false) {
            return false;
        }

        if ($connections === self::CONNECTIONS_INCREASE) {
            $allSitecalls[$sitecallKey]['data']['general']['connections']++;
        } else {
            $allSitecalls[$sitecallKey]['data']['general']['connections'] = $connections;
        }

        self::setAll($allSitecalls);

        return true;
    }
}
