<?php
require_once( 'class.focussitecalllite-sitecalls-model.php' );
require_once( 'class.focussitecalllite-model.php' );
require_once( 'class.focussitecalllite-templates-sitecalls-model.php' );

if ( ! class_exists( 'WP_List_Table' ) ) {
	require_once( ABSPATH . 'wp-admin/includes/class-wp-list-table.php' );
}

class FocusSitecallLite_Templates_Sitecalls_List_Table extends WP_List_Table {

	public function __construct( $args = array() ) {
		parent::__construct( $args );
	}

	public function prepare_items() {
		$columns  = $this->get_columns();
		$hidden   = $this->get_hidden_columns();
		$sortable = $this->get_sortable_columns();
		$data     = $this->table_data();

		usort( $data, array( &$this, 'sort_data' ) );

		$perPage = 10;

		$currentPage = $this->get_pagenum();
		$totalItems  = count( $data );
		$this->set_pagination_args( array(
			'total_items' => $totalItems,
			'per_page'    => $totalItems
		) );
		$data                  = array_slice( $data, ( ( $currentPage - 1 ) * $perPage ), $perPage );
		$this->_column_headers = array( $columns, $hidden, $sortable );
		$this->items           = $data;
	}

	public function get_columns() {
		$columns = array(
			'cb'       => '<input type="checkbox" />',
			'name'     => __('Theme name', 'focus-sitecall-lite'),
			'sitecall' => __('SiteCall', 'focus-sitecall-lite')
		);

		return $columns;
	}

	public function get_hidden_columns() {
		return array();
	}

	public function get_sortable_columns() {
		return array();
	}

	private function table_data() {
		$templates = array_keys( get_page_templates() );
		array_unshift( $templates, FocusSitecallLite_Templates_Sitecalls_Model::getDefaultTemplateName() );

		$sitecalls         = FocusSitecallLite_Sitecalls_Model::getAll();
		$templatesitecalls = FocusSitecallLite_Templates_Sitecalls_Model::getAll();

		$templates_data = [];
		foreach ( $templates as $template ) {

			$sitecallname = '';

			if ( isset( $templatesitecalls[ $template ] ) ) {

				$sitecallkey  = array_search( $templatesitecalls[ $template ], array_column( $sitecalls, 'id' ) );
				$sitecallname = $sitecallkey !== false && isset( $sitecalls[ $sitecallkey ]['name'] ) ? $sitecalls[ $sitecallkey ]['name'] : '';

			}

			$templates_data[] = [
				'name'     => $template,
				'sitecall' => $sitecallname
			];
		}

		return $templates_data;
	}

	public function column_default( $item, $column_name ) {
		switch ( $column_name ) {
			case 'name':
			case 'sitecall':
				return $item[ $column_name ];
			default:
				return print_r( $item, true );
		}
	}

	public function column_cb( $item ) {
		return sprintf(
			'<input type="checkbox" name="bulk-assign[]" value="%s" />', $item['name']
		);
	}

	public function get_bulk_actions() {
		return [];
	}


	public function extra_tablenav( $which ) {
		if ( $which == "bottom" || $which == "top" ) {
			if ( FocusSitecallLite_Sitecalls_Model::getAll() ) {
				echo '<div class="alignleft actions bulkactions">';
				echo '<span class="alignleft" style="margin: 5px">' . __('Assign SiteCall to template:', 'focus-sitecall-lite') . '</span>';
				echo FocusSitecallLite_Sitecalls_Model::getDropdown( 'assignTo[]',
					[
						'value' => '0',
						'name'  => __('(none)', 'focus-sitecall-lite')
					] );
				echo '<input style="margin-right: 50px" type="submit" value="' . __('Assign', 'focus-sitecall-lite') . '" class="button" />';
				echo '</div>';
			}
		}
		if ( $which == 'top' ) {
			_e('Default SiteCall for theme: ', 'focus-sitecall-lite');
			echo FocusSitecallLite_Sitecalls_Model::getDropdown(
				'default_global_sitecall',
				[
					'value' => '0',
					'name'  => __('(none)', 'focus-sitecall-lite')
				],
				get_option( FocusSitecallLite_Model::SITECALL_DEFAULT_GLOBAL_OPTION_KEY ) );
			echo '<input type="submit" name="default_global_sitecall_button" value="' . __('Choose', 'focus-sitecall-lite') . '" class="button" />';
		}
	}

    public function get_pagenum() {
        $pagenum = isset( $_REQUEST['paged2'] ) ? absint( $_REQUEST['paged2'] ) : 0;

        if ( isset( $this->_pagination_args['total_pages'] ) && $pagenum > $this->_pagination_args['total_pages'] )
            $pagenum = $this->_pagination_args['total_pages'];

        return max( 1, $pagenum );
    }
}
